==> zio-aws-route53recoverycontrolconfig_3-5.17.104.8-sources.jar: zio/aws/route53recoverycontrolconfig/model/DeleteRoutingControlRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteRoutingControlRequest(routingControlArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteRoutingControlRequest = {
    import DeleteRoutingControlRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteRoutingControlRequest
      .builder()
      .routingControlArn(__string.unwrap(routingControlArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DeleteRoutingControlRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DeleteRoutingControlRequest
      .wrap(buildAwsValue())
}
object DeleteRoutingControlRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteRoutingControlRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DeleteRoutingControlRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DeleteRoutingControlRequest(routingControlArn)
    def routingControlArn: __string
    def getRoutingControlArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(routingControlArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteRoutingControlRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DeleteRoutingControlRequest.ReadOnly {
    override val routingControlArn: __string =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__string(impl.routingControlArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteRoutingControlRequest
  ): zio.aws.route53recoverycontrolconfig.model.DeleteRoutingControlRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_3-5.20.22.3-sources.jar: zio/aws/route53recoverycontrolconfig/model/DeleteRoutingControlRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteRoutingControlRequest(routingControlArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteRoutingControlRequest = {
    import DeleteRoutingControlRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteRoutingControlRequest
      .builder()
      .routingControlArn(routingControlArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DeleteRoutingControlRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DeleteRoutingControlRequest
      .wrap(buildAwsValue())
}
object DeleteRoutingControlRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteRoutingControlRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DeleteRoutingControlRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DeleteRoutingControlRequest(routingControlArn)
    def routingControlArn: __string
    def getRoutingControlArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(routingControlArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteRoutingControlRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DeleteRoutingControlRequest.ReadOnly {
    override val routingControlArn: __string =
      impl.routingControlArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteRoutingControlRequest
  ): zio.aws.route53recoverycontrolconfig.model.DeleteRoutingControlRequest.ReadOnly =
    new Wrapper(impl)
}
